-- dG Killshot Notifier
-- Written by Ratchet and Gib of Kil'Jaeden
-- Updated by Delthis of Kil'Jaeden
-- 
-- Simple enough. Adds sounds to let you know that you got the killshot. Also syncs with raid.
-- Inspired by a mod written by Calixta of Kil'Jaeden
-- Idea for NPC / PC filtering from Mik's Scrolling Battle Text
-- 
-- Access help with '/ks'
--
-- Changelog:
-- 20300.0.01  112607	Updated .toc for 2.3 patch
--			Added limited soundpack support
--			Added configurable kill message with slash command
--			Added raidscore slash command
--			Updated default sound files
--			Added new kill ranks
-- 20200.0.01  092607   Updated .toc for 2.2 patch
-- 20100.0.01  092207   Updated .toc for 2.1 patch
--			Added "Eye of the Storm" Support
-- 20003.0.01  010907   Updated .toc for 2.0.3 patch
-- 11200.0.08: 112206   Initial Multikill Support
--			Fix for PlaySoundFile()
--			Adjusted killingstreak ranks down
--			Slight code cleanup
--			Initial Config GUI code
-- 11200.0.07: 112106   Initial Duel Support
-- 11200.0.06: 102406   Real player/npc filtering
-- 11200.0.05: 101206   Fixed an Event unregistering bug
--			Moved sounds files into sounds dir
--			Added initial msbt support untested	
-- 11200.0.04: 100306	Converted to support Ace2 library
--			Added initial BG Only Mode
--			Added simple npc check
-- 11200.0.03: 090306   Added Raid Sync
--			Added Blizzard_CombatText Integration
--			Added SCT Integration
-- 11200.0.02: 090106	Added killing streaks
--			Added help feature			
-- 11200.0.01: 090106	Initial Version 
--
-- Todo:
-- Graphical Configuration
--

-----------------------
-- PRIVATE CONSTANTS --
-----------------------

-- Edit these to adjust killingstreak ranks --
KSRANK1 = 2;
KSRANK2 = 4;
KSRANK3 = 6;
KSRANK4 = 8;
KSRANK5 = 10;
KSRANK6 = 12;
KSRANK7 = 14;
-- End of editable killing streak ranks --

-- Sound Files
-- Names must be the same for each addon
KSSOUND1 = "ownage.wav";
KSSOUND2 = "killingspree.wav";
KSSOUND3 = "rampage.wav";
KSSOUND4 = "dominating.wav";
KSSOUND5 = "unstoppable.wav";
KSSOUND6 = "godlike.wav";
KSSOUND7 = "whickedsick.wav";
KSSOUNDM1 = "doublekill.wav";
KSSOUNDM2 = "multikill.wav";
KSSOUNDM3 = "megakill.wav";
KSSOUNDM4 = "ultrakill.wav";
KSSOUNDM5 = "monsterkill.wav";
KSSOUNDM6 = "ludicrouskill.wav";
KSSOUNDM7 = "holyshit.wav";
KSSOUNDH = "humiliation.wav";

-- Multikill Text
KSTEXTM1 = "DOUBLEKILL!";
KSTEXTM2 = "MULTIKILL!";
KSTEXTM3 = "MEGAKILL!";
KSTEXTM4 = "ULTRAKILL!!!";
KSTEXTM5 = "MONSTERKILL!!!";
KSTEXTM6 = "LUDICROUSKILL!!!";
KSTEXTM7 = "H O L Y  S H I T!!!";

-- Amount of time to delay between selected player list updates and how long
-- to hold a recently selected player in cache.
local RECENTLY_SELECTED_PLAYERS_UPDATE_INTERVAL = 1;
local RECENTLY_SELECTED_PLAYERS_HOLD_TIME = 45;

-----------------------
-- PRIVATE VARIABLES --
-----------------------

local killingstreak = 0;
local dgks_playername = UnitName("player");
local dgks_multikill = 0;
local dgks_lastkill = 0;


-- Holds a list of recently selected hostile players.
local recentlySelectedPlayers = {};
local elapsedTime = 0;

-- Setup the Ace2 slash commands
local options = { 
	type='group',
	args = {
		sound = {
			type = 'toggle',
			name = 'Play Sound',
			desc = 'Toggles the playing of the audible message',
			get = "issound",
			set = "togglesound"
		},
		emote = {
			type = 'toggle',
			name = 'Show Emote',
			desc = 'Toggles the display of the emote',
			get = "isemote",
			set = "toggleemote"
		},
		bgonly = {
			type = 'toggle',
			name = 'Battleground Only',
			desc = 'Toggles battleground only mode',
			get = "isbgonly",
			set = "togglebgonly"
		},
		raid = {
			type = 'toggle',
			name = 'Sync with Raid',
			desc = 'Toggles the syncing the message with raid',
			get = "israid",
			set = "toggleraid"
		},
		-- ENABLE FOR DEBUGGING
		test = {
			type = 'execute',
			name = 'Test dgks',
			desc = 'Test dgks message output',
			func = "dgks_Killshot"
		},
		score = {
			type = 'execute',
			name = 'Print KillingStreak',
			desc = 'Print KillingStreak',
			func = "dgks_KillingStreak"
		},
		--config = {
		--	type = 'execute',
		--	name = 'Show Config',
		--	desc = 'Show Config',
		--	func = "dgks_toggleConfig"
		--}
		msg = {
		            type = 'text',
		            name = 'Killshot Message',
		            desc = 'Killshot Message',
		            usage = "<message>",
		            get = "getMessage",
		            set = "setMessage"
        	},
		raidscore = {
		            type = 'execute',
		            name = 'Print KillingStreak to raid',
		            desc = 'Print KillingStreak to raid',
		            func = "dgks_raidScore"
        	},
		soundpack = {
		            type = 'text',
		            name = 'Sound Pack',
		            desc = 'Choose a sound pack',
		            usage = "Options are <male>, <female>, and <sexy>",
		            get = "getSoundPack",
		            set = "setSoundPack"
        	}
	}
};

--------------------
-- DGKS MAIN CODE --
--------------------

-- Create the Ace2 main object
dgks = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0");

-- Register the Ace2 / commands
dgks:RegisterChatCommand({"/dgks", "/ks"}, options)

-- Register default options
dgks:RegisterDB("dgksDB", "dgksDBPC");
dgks:RegisterDefaults("profile", {
	sound = true,
	emote = false,
	bgonly = false,
	raid = true,
	ksmsg = "has killed",
	soundpack = "male",
	soundpath = "Interface\\AddOns\\dgks\\sounds\\"
} );

-- Setup the Ace2 slash command functions
function dgks:issound()
	return self.db.profile.sound;
end

function dgks:togglesound()
	self.db.profile.sound = not self.db.profile.sound;
end

function dgks:isemote()
	return self.db.profile.emote;
end

function dgks:toggleemote()
	self.db.profile.emote = not self.db.profile.emote;
end

function dgks:getMessage()
	return self.db.profile.ksmsg;
end

function dgks:setMessage(newmsg)
	self.db.profile.ksmsg = newmsg;
end

function dgks:getSoundPack()
	return self.db.profile.soundpack;
end

function dgks:setSoundPack(newsoundset)
	
	if (newsoundset == "male") then
		self.db.profile.soundpack = newsoundset;
		self.db.profile.soundpath = "Interface\\AddOns\\dgks\\sounds\\";
	elseif (newsoundset == "female") then
		if (IsAddOnLoaded("dgks_female")) then
			self.db.profile.soundpack = newsoundset;
			self.db.profile.soundpath = "Interface\\AddOns\\dgks_female\\";
		else 
			message("That addon is not enabled");
		end
	elseif (newsoundset == "sexy") then
		if (IsAddOnLoaded("dgks_sexy")) then
			self.db.profile.soundpack = newsoundset;
			self.db.profile.soundpath = "Interface\\AddOns\\dgks_sexy\\";
		else 
			message("That addon is not enabled");
		end
	else
		message("Error: That is not a valid option");
	end
end

function dgks:isbgonly()
	return self.db.profile.bgonly;
end

function dgks:togglebgonly()
	-- toggle current setting
	self.db.profile.bgonly = not self.db.profile.bgonly;

	-- if bg only mode watch zone changes
	if (self.db.profile.bgonly) then
		-- Setup bg only mode
		self:RegisterEvent("ZONE_CHANGED_NEW_AREA");
		-- Check to see if we are in bg or not
		dgks:ZONE_CHANGED_NEW_AREA();
	else
		-- Setup all the time mode
		self:UnregisterEvent("ZONE_CHANGED_NEW_AREA");
		self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH");
		self:RegisterEvent("CHAT_MSG_SYSTEM");
		self:RegisterEvent("PLAYER_DEAD");
		self:RegisterEvent("CHAT_MSG_ADDON");
		self:RegisterEvent("PLAYER_TARGET_CHANGED");
	end

	
end

function dgks:israid()
	return self.db.profile.raid;
end

function dgks:toggleraid()
	self.db.profile.raid = not self.db.profile.raid;
end

function dgks:OnUpdate(arg1)
	-- Increment the amount of time passed since the last update.
	elapsedTime = elapsedTime + arg1;

	-- Check if it's time for an update.
	if (elapsedTime >= RECENTLY_SELECTED_PLAYERS_UPDATE_INTERVAL) then
		-- Loop through all of the recently selected players.
		for playerName, lastSeen in recentlySelectedPlayers do
			-- Increment the amount of time since the player was last seen.
			recentlySelectedPlayers[playerName] = lastSeen + elapsedTime;

			-- Check if enough time has passed and remove the player from the list.
			if (lastSeen + elapsedTime >= RECENTLY_SELECTED_PLAYERS_HOLD_TIME) then
				recentlySelectedPlayers[playerName] = nil;
			end
		end

		-- Reset the elapsed time.
		elapsedTime = 0;
	end
end	

function dgks:OnEnable()
	-- Called when the addon is enabled
	self:RegisterEvent("dgks_PlaySoundFile");
	if (self.db.profile.bgonly) then
		self:RegisterEvent("ZONE_CHANGED_NEW_AREA");
	else
		self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH");
		self:RegisterEvent("CHAT_MSG_SYSTEM");
		self:RegisterEvent("PLAYER_DEAD");
		self:RegisterEvent("CHAT_MSG_ADDON");
		self:RegisterEvent("PLAYER_TARGET_CHANGED");
	end
end

function dgks:CHAT_MSG_COMBAT_HOSTILE_DEATH(arg1)
	if (string.find (arg1, "You have slain ")) then
	-- KILLSHOT!
		killingstreak = dgks:dgks_Killshot(arg1, killingstreak);
	end	
end

function dgks:CHAT_MSG_SYSTEM(arg1)
	if (string.find (arg1, dgks_playername .. " has defeated ")) then
		-- Duel won!
		if ( killingstreak < KSRANK1) then 
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND1", "RAID");
			dgks:dgks_SoundPack(KSSOUND1);
		elseif (killingstreak < KSRANK2) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND2", "RAID");
			dgks:dgks_SoundPack(KSSOUND2);
		elseif (killingstreak < KSRANK3) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND3", "RAID");
			dgks:dgks_SoundPack(KSSOUND3);
		elseif (killingstreak < KSRANK4) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND4", "RAID");
			dgks:dgks_SoundPack(KSSOUND4);
		elseif (killingsteak < KSRANK5) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND5", "RAID");
			dgks:dgks_SoundPack(KSSOUND5);
		elseif (killingsteak < KSRANK6) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND5", "RAID");
			dgks:dgks_SoundPack(KSSOUND6);
		elseif (killingstreak > (KSRANK6 - 1)) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND6", "RAID");
			dgks:dgks_SoundPack(KSSOUND7);
		end
		-- Increment killingblow streak
		killingstreak = killingstreak + 1;
		dgks:dgks_SendAddonMessage("dgks_txt", arg1, "RAID");
		dgks:dgks_Blamo(arg1);
	elseif (string.find (arg1, "has defeated " .. dgks_playername .. " in a duel.")) then
		-- Duel lost!
		killingstreak = 0;
		dgks:dgks_SendAddonMessage("dgks_txt", arg1, "RAID");
	end
	if (string.find(arg1, dgks_playername .. " has fled from ")) then
		-- lol u ran from a duel
		dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDH", "RAID");
		dgks:dgks_SoundPack(KSSOUNDH);
		dgks:dgks_Blamo(arg1);
		dgks:dgks_SendAddonMessage("dgks_txt", arg1, "RAID");
	end
end		

function dgks:PLAYER_DEAD()
	-- Player has died. End killing streak.
	killingstreak = 0;
end

function dgks:CHAT_MSG_ADDON(arg1,arg2,arg3,arg4)
	if not (arg4 == dgks_playername) then
		if (arg1 == "dgks") then		
			dgks:dgks_Blamo(arg4 .. arg2);
		
		elseif (arg1 == "dgks_snd") then
			if arg2 == "KSSOUND1" then
				dgks:dgks_SoundPack(KSSOUND1);
			elseif arg2 == "KSSOUND2" then
				dgks:dgks_SoundPack(KSSOUND2);
			elseif arg2 == "KSSOUND3" then
				dgks:dgks_SoundPack(KSSOUND3);
			elseif arg2 == "KSSOUND4" then
				dgks:dgks_SoundPack(KSSOUND4);
			elseif arg2 == "KSSOUND5" then
				dgks:dgks_SoundPack(KSSOUND5);
			elseif arg2 == "KSSOUND6" then
				dgks:dgks_SoundPack(KSSOUND6);
			elseif arg2 == "KSSOUND7" then
				dgks:dgks_SoundPack(KSSOUND7);
			elseif arg2 == "KSSOUNDM1" then
				dgks:dgks_SoundPack(KSSOUNDM1);
			elseif arg2 == "KSSOUNDM2" then
				dgks:dgks_SoundPack(KSSOUNDM2);
			elseif arg2 == "KSSOUNDM3" then
				dgks:dgks_SoundPack(KSSOUNDM3);
			elseif arg2 == "KSSOUNDM4" then
				dgks:dgks_SoundPack(KSSOUNDM4);
			elseif arg2 == "KSSOUNDM5" then
				dgks:dgks_SoundPack(KSSOUNDM5);
			elseif arg2 == "KSSOUNDM6" then
				dgks:dgks_SoundPack(KSSOUNDM6);
			elseif arg2 == "KSSOUNDM7" then
				dgks:dgks_SoundPack(KSSOUNDM7);
			elseif arg2 == "KSSOUNDH" then
				dgks:dgks_SoundPack(KSSOUNDH);
			end
		elseif (arg1 == "dgks_txt") then
			dgks:dgks_Print(arg2);
		end
	end
end

function dgks:ZONE_CHANGED_NEW_AREA()

	local dgks_newzone = GetZoneText();

	if ((dgks_newzone == "Warsong Gulch") or (dgks_newzone == "Eye of the Storm") or (dgks_newzone == "Arathi Basin") or (dgks_newzone == "Alterac Valley")) then
		self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH");
		self:RegisterEvent("PLAYER_DEAD");
		self:RegisterEvent("CHAT_MSG_ADDON");
		self:RegisterEvent("PLAYER_TARGET_CHANGED");
	else
		if self:IsEventRegistered("CHAT_MSG_COMBAT_HOSTILE_DEATH") then
			self:UnregisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH");
			self:UnregisterEvent("PLAYER_DEAD");
			self:UnregisterEvent("CHAT_MSG_ADDON");
			self:UnregisterEvent("PLAYER_TARGET_CHANGED");
		end
	end
end

function dgks:PLAYER_TARGET_CHANGED()
	-- Make sure a unit is selected, is a player and is hostile.
	if (UnitExists("target") and UnitIsPlayer("target") and not UnitIsFriend("player", "target")) then
		-- Get the unit's name and make sure it's valid before adding it to the recently selected player's list.
		local playerName = UnitName("target");
		if (playerName) then
			recentlySelectedPlayers[playerName] = 0;
		end
	end	
end

function dgks:dgks_Print(msg)
	-- New school Ace2 style
	dgks:Print(msg);
end

function dgks:dgks_Blamo(msg)
	if (IsAddOnLoaded("Blizzard_CombatText")) then
	-- If Blizzard CombatText enable send msg there
		CombatText_AddMessage(msg, CombatText_StandardSCroll, 1, 0.1, 0.1, "crit", 0);		
	elseif (IsAddOnLoaded("SCT")) then
		-- If SCT is loaded send msg there
		color = {r=1.0, g=0.1, b=0.1};			
		SCT:DisplayText(msg, color, 1, "event", 1, 1); 			
	elseif (IsAddOnLoaded("MikScrollingBattleText")) then
		-- If Mik's Scrolling Battle Text is loaded send msg here
 		MikSBT.DisplayMessage(msg, MikSBT.DISPLAYTYPE_OUTGOING, false, 0, 0, 255);
	end
	-- Last and least just send it to the text box if no scrolling text available.
	dgks:dgks_Print(msg);
end

function dgks:dgks_Killshot(arg1, arg2)

	-- Do some PC/NPC checking before we get all excited and flag a kill
	-- There has got to be a better way to do this, but as of now this is my rig
	local npc = 1;
	
	-- Make sure arg2 is not nil
	if (arg2 == nil) then
		arg2 = 0;
	end
	
	-- If arg1 is nil then this must be a test	
	if (arg1 == nil) then
		arg1 = "You have slain Test."
		npc = 0;
		-- DEBUG arg2 = arg2 - 1;
	end

	-- Get name from kill string
	local dgks_victimname = string.sub(arg1,16,-2);
   

	-- Check if the current target is the slain enemy and is a player, or the slain target is on the recently
	-- selected players list.
	if ((UnitExists("target") and (UnitName("target") == dgks_victimname) and UnitIsPlayer("target")) or (recentlySelectedPlayers[dgks_victimname] ~= nil)) then
		npc = 0;
	end
	
	
	if npc==0 then
		-- PLAYER GOT KILLSHOT
		-- Emote Enabled
		if (self.db.profile.emote) then
			SendChatMessage("has destroyed " .. dgks_victimname, "EMOTE");
		end
	
		-- Print to SCT or Text Box
		dgks:dgks_Blamo(dgks_playername .. " " .. self.db.profile.ksmsg .. " " ..  dgks_victimname);	

		dgks:dgks_SendAddonMessage("dgks", " " .. self.db.profile.ksmsg .. " " ..  dgks_victimname, "RAID");

		-- Play correct sounds and send to raid
		if (arg2 < KSRANK1) then 
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND1", "RAID");
			dgks:dgks_SoundPack(KSSOUND1);
		elseif (arg2 < KSRANK2) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND2", "RAID");
			dgks:dgks_SoundPack(KSSOUND2);
		elseif (arg2 < KSRANK3) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND3", "RAID");
			dgks:dgks_SoundPack(KSSOUND3);
		elseif (arg2 < KSRANK4) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND4", "RAID");
			dgks:dgks_SoundPack(KSSOUND4);
		elseif (arg2 < KSRANK5) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND5", "RAID");
			dgks:dgks_SoundPack(KSSOUND5);
		elseif (arg2 < KSRANK6) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND5", "RAID");
			dgks:dgks_SoundPack(KSSOUND6);
		elseif (arg2 > (KSRANK6 - 1)) then
			dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUND6", "RAID");
			dgks:dgks_SoundPack(KSSOUND7);
		end
		
		-- Check for multikill
		local dgks_thiskill = GetTime();
		if((dgks_lastkill + 5) > dgks_thiskill) then
			-- multikill!!
			dgks_multikill = dgks_multikill + 1;
			if (dgks_multikill == 2) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM1", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM1, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM1);
				dgks:dgks_SoundPack(KSSOUNDM1);
			elseif (dgks_multikill == 3) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM2", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM2, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM2);
				dgks:dgks_SoundPack(KSSOUNDM2);
			elseif (dgks_multikill == 4) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM3", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM3, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM3);
				dgks:dgks_SoundPack(KSSOUNDM3);
			elseif (dgks_multikill == 5) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM4", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM4, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM4);
				dgks:dgks_SoundPack(KSSOUNDM4);
			elseif (dgks_multikill == 6) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM5", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM5, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM5);
				dgks:dgks_SoundPack(KSSOUNDM5);
			elseif (dgks_multikill == 7) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM6", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM6, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM6);
				dgks:dgks_SoundPack(KSSOUNDM6);
			elseif (dgks_multikill > 7) then
				dgks:dgks_SendAddonMessage("dgks_snd", "KSSOUNDM7", "RAID");
				dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. " has got a " .. KSTEXTM7, "RAID");
				dgks:Print(dgks_playername .. " has got a " .. KSTEXTM7);
				dgks:dgks_SoundPack(KSSOUNDM7);
			end 
			
		else
			-- last kill was more than 5 seconds ago
			dgks_multikill = 1;
		end		
		dgks_lastkill = dgks_thiskill;

		-- Increment killingblow streak
		return arg2+1;
	end
	-- Since it was an npc dont increment our killingblow streak
	return arg2;
end

function dgks:dgks_PlaySoundFile(arg1)
	if(self.db.profile.sound) then
		if not (PlaySoundFile(arg1)) then
			self:ScheduleEvent("dgks_PlaySoundFile", 0.2	, arg1);
		end		
	end
end

function dgks:dgks_SoundPack(arg1)
	soundfile = self.db.profile.soundpath .. arg1;
	
	--DEBUG
	--dgks:Print(soundfile);
	
	dgks:dgks_PlaySoundFile(soundfile);
end

function dgks:dgks_SendAddonMessage(arg1, arg2, arg3)
	if(self.db.profile.raid) then
		SendAddonMessage(arg1, arg2, arg3);
	end
end

function dgks:dgks_KillingStreak()
	dgks:dgks_Print("KillingStreak: " .. killingstreak);
end

function dgks:dgks_raidScore()
	dgks:dgks_SendAddonMessage("dgks_txt", dgks_playername .. "'s KillingStreak: " .. killingstreak, "RAID");
	dgks:dgks_Print("KillingStreak: " .. killingstreak);
end

function dgks:dgks_toggleConfig()
	if not dgks_configframe then 
		dgks_configframe = CreateFrame("Frame",nil,UIParent);
		dgks_configframe:SetFrameStrata("BACKGROUND");
		dgks_configframe:SetWidth(128);  -- Set These to whatever height/width is needed 
		dgks_configframe:SetHeight(64); -- for your Texture

		dgks_configtexture = dgks_configframe:CreateTexture(nil,"BACKGROUND");
		dgks_configtexture:SetTexture("Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Factions.blp");
		dgks_configtexture:SetAllPoints(dgks_configframe);
		dgks_configframe.texture = dgks_configframe;

		dgks_configframe:SetPoint("CENTER",0,0);
		dgks_configframe:Show();
	end
	if(dgks_configframe:IsVisible()) then
		dgks_configframe:Hide();
	else
		dgks_configframe:Show();
	end
end
	
